package com.ruoyi.zongzhi.controller;

import java.util.List;
import io.swagger.annotations.Api;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.zongzhi.domain.TcDtSx;
import com.ruoyi.zongzhi.service.ITcDtSxService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 动态筛选Controller
 * 
 * @author ruoyi
 * @date 2023-08-28
 */
@RestController
@RequestMapping("/zongzhi/sx")
@Api(tags = " 动态筛选")
public class TcDtSxController extends BaseController
{
    @Autowired
    private ITcDtSxService tcDtSxService;

    /**
     * 查询动态筛选列表
     */
    @PreAuthorize("@ss.hasPermi('zongzhi:sx:list')")
    @GetMapping("/list")
    public TableDataInfo list(TcDtSx tcDtSx)
    {
        startPage();
        List<TcDtSx> list = tcDtSxService.selectTcDtSxList(tcDtSx);
        return getDataTable(list);
    }

    /**
     * 导出动态筛选列表
     */
    @PreAuthorize("@ss.hasPermi('zongzhi:sx:export')")
    @Log(title = "动态筛选", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TcDtSx tcDtSx)
    {
        List<TcDtSx> list = tcDtSxService.selectTcDtSxList(tcDtSx);
        ExcelUtil<TcDtSx> util = new ExcelUtil<TcDtSx>(TcDtSx.class);
        util.exportExcel(response, list, "动态筛选数据");
    }

    /**
     * 获取动态筛选详细信息
     */
    @PreAuthorize("@ss.hasPermi('zongzhi:sx:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tcDtSxService.selectTcDtSxById(id));
    }

    /**
     * 新增动态筛选
     */
    @PreAuthorize("@ss.hasPermi('zongzhi:sx:add')")
    @Log(title = "动态筛选", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TcDtSx tcDtSx)
    {
        return toAjax(tcDtSxService.insertTcDtSx(tcDtSx));
    }

    /**
     * 修改动态筛选
     */
    @PreAuthorize("@ss.hasPermi('zongzhi:sx:edit')")
    @Log(title = "动态筛选", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TcDtSx tcDtSx)
    {
        return toAjax(tcDtSxService.updateTcDtSx(tcDtSx));
    }

    /**
     * 删除动态筛选
     */
    @PreAuthorize("@ss.hasPermi('zongzhi:sx:remove')")
    @Log(title = "动态筛选", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tcDtSxService.deleteTcDtSxByIds(ids));
    }
}
