package com.ruoyi.zongzhi.controller;

import java.util.List;
import io.swagger.annotations.Api;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.zongzhi.domain.TcYqFl;
import com.ruoyi.zongzhi.service.ITcYqFlService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 舆情分类Controller
 * 
 * @author ruoyi
 * @date 2023-08-28
 */
@RestController
@RequestMapping("/zongzhi/fl")
@Api(tags = " 舆情分类")
public class TcYqFlController extends BaseController
{
    @Autowired
    private ITcYqFlService tcYqFlService;

    /**
     * 查询舆情分类列表
     */
    @PreAuthorize("@ss.hasPermi('zongzhi:fl:list')")
    @GetMapping("/list")
    public TableDataInfo list(TcYqFl tcYqFl)
    {
        startPage();
        List<TcYqFl> list = tcYqFlService.selectTcYqFlList(tcYqFl);
        return getDataTable(list);
    }

    /**
     * 导出舆情分类列表
     */
    @PreAuthorize("@ss.hasPermi('zongzhi:fl:export')")
    @Log(title = "舆情分类", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TcYqFl tcYqFl)
    {
        List<TcYqFl> list = tcYqFlService.selectTcYqFlList(tcYqFl);
        ExcelUtil<TcYqFl> util = new ExcelUtil<TcYqFl>(TcYqFl.class);
        util.exportExcel(response, list, "舆情分类数据");
    }

    /**
     * 获取舆情分类详细信息
     */
    @PreAuthorize("@ss.hasPermi('zongzhi:fl:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tcYqFlService.selectTcYqFlById(id));
    }

    /**
     * 新增舆情分类
     */
    @PreAuthorize("@ss.hasPermi('zongzhi:fl:add')")
    @Log(title = "舆情分类", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TcYqFl tcYqFl)
    {
        return toAjax(tcYqFlService.insertTcYqFl(tcYqFl));
    }

    /**
     * 修改舆情分类
     */
    @PreAuthorize("@ss.hasPermi('zongzhi:fl:edit')")
    @Log(title = "舆情分类", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TcYqFl tcYqFl)
    {
        return toAjax(tcYqFlService.updateTcYqFl(tcYqFl));
    }

    /**
     * 删除舆情分类
     */
    @PreAuthorize("@ss.hasPermi('zongzhi:fl:remove')")
    @Log(title = "舆情分类", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tcYqFlService.deleteTcYqFlByIds(ids));
    }
}
