package com.ruoyi.zongzhi.controller;

import java.util.List;
import io.swagger.annotations.Api;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.zongzhi.domain.TcYqZs;
import com.ruoyi.zongzhi.service.ITcYqZsService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 舆情走势图Controller
 * 
 * @author ruoyi
 * @date 2023-08-28
 */
@RestController
@RequestMapping("/zongzhi/zs")
@Api(tags = " 舆情走势图")
public class TcYqZsController extends BaseController
{
    @Autowired
    private ITcYqZsService tcYqZsService;

    /**
     * 查询舆情走势图列表
     */
    @PreAuthorize("@ss.hasPermi('zongzhi:zs:list')")
    @GetMapping("/list")
    public TableDataInfo list(TcYqZs tcYqZs)
    {
        startPage();
        List<TcYqZs> list = tcYqZsService.selectTcYqZsList(tcYqZs);
        return getDataTable(list);
    }

    /**
     * 导出舆情走势图列表
     */
    @PreAuthorize("@ss.hasPermi('zongzhi:zs:export')")
    @Log(title = "舆情走势图", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TcYqZs tcYqZs)
    {
        List<TcYqZs> list = tcYqZsService.selectTcYqZsList(tcYqZs);
        ExcelUtil<TcYqZs> util = new ExcelUtil<TcYqZs>(TcYqZs.class);
        util.exportExcel(response, list, "舆情走势图数据");
    }

    /**
     * 获取舆情走势图详细信息
     */
    @PreAuthorize("@ss.hasPermi('zongzhi:zs:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tcYqZsService.selectTcYqZsById(id));
    }

    /**
     * 新增舆情走势图
     */
    @PreAuthorize("@ss.hasPermi('zongzhi:zs:add')")
    @Log(title = "舆情走势图", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TcYqZs tcYqZs)
    {
        return toAjax(tcYqZsService.insertTcYqZs(tcYqZs));
    }

    /**
     * 修改舆情走势图
     */
    @PreAuthorize("@ss.hasPermi('zongzhi:zs:edit')")
    @Log(title = "舆情走势图", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TcYqZs tcYqZs)
    {
        return toAjax(tcYqZsService.updateTcYqZs(tcYqZs));
    }

    /**
     * 删除舆情走势图
     */
    @PreAuthorize("@ss.hasPermi('zongzhi:zs:remove')")
    @Log(title = "舆情走势图", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tcYqZsService.deleteTcYqZsByIds(ids));
    }
}
